@@ -1,23 +1,24 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-10 14:14:53
-# @Last Modified time: 2021-03-26 14:43:45
+# @Last Modified time: 2021-11-16 17:34:45
 # @github: https://github.com/longfengpili
 
 # !/usr/bin/env python3
 # -*- coding:utf-8 -*-
 
+import re
 import os
 import sys
 import colorlog
 
-
 AUTO_RULES = ['test_xu']  # 可以自动执行表名（表名包含即可）
 REDSHIFT_AUTO_RULES = AUTO_RULES + ['_data_aniland']  # Amazon Redshift 可以自动执行表名（表名包含即可）
 
 # logging settings
 USERPATH = os.environ['USERPROFILE'] if 'USERPROFILE' in os.environ else os.environ['HOME'] if 'HOME' in os.environ else ''
-LOG_BASE_PATH = os.path.join(USERPATH, 'pydbapilog')  # 可以user目录下查看日志
+LOG_BASE_PATH = os.path.join(USERPATH, '.pydbapilog')  # 可以user目录下查看日志
+PROJECT_NAME = re.sub(':?\\\\', '_', os.getcwd())
 LOGGING_CONFIG = {
     'version': 1,  # 保留字
     'disable_existing_loggers': False,  # 禁用已经存在的logger实例
@@ -67,7 +68,7 @@ LOGGING_CONFIG = {
         'default': {
             'level': 'INFO',
             'class': 'pydbapi.conf.MakeFileHandler',  # 能够判断创建日持文件
-            'filename': os.path.join(LOG_BASE_PATH, 'default.log'),  # 日志文件
+            'filename': os.path.join(LOG_BASE_PATH, f'{PROJECT_NAME}_default.log'),  # 日志文件
             'when': 'd',  # 每天备份
             'interval': 1,
             'backupCount': 30,  # 最多备份几个
@@ -77,7 +78,7 @@ LOGGING_CONFIG = {
         'db': {
             'level': 'INFO',
             'class': 'pydbapi.conf.MakeFileHandler',  # 保存到文件，自动切
-            'filename': os.path.join(LOG_BASE_PATH, 'db.log'),  # 日志文件
+            'filename': os.path.join(LOG_BASE_PATH, f'{PROJECT_NAME}_db.log'),  # 日志文件
             'when': 'd',  # 每小时备份
             'interval': 1,
             'backupCount': 30,
@@ -87,7 +88,7 @@ LOGGING_CONFIG = {
         'sql': {
             'level': 'INFO',
             'class': 'logging.handlers.TimedRotatingFileHandler',  # 保存到文件，自动切
-            'filename': os.path.join(LOG_BASE_PATH, 'sql.log'),  # 日志文件
+            'filename': os.path.join(LOG_BASE_PATH, f'{PROJECT_NAME}_sql.log'),  # 日志文件
             'when': 'd',  # 每小时备份
             'interval': 1,
             'backupCount': 30,
@@ -99,7 +100,7 @@ LOGGING_CONFIG = {
         # 默认的logger应用如下配置
         '': {
             'handlers': ['console', 'default'],
-            'level': 'WARNING',
+            'level': 'INFO',
             'propagate': True,  # 向不向更高级别的logger传递
         },
         'db': {
